@@ -5,6 +5,7 @@ from collections import OrderedDict
 from pathlib import Path
 from typing import Optional
 
+import dbt.config.profile as dbt_profile
 import feedparser
 import pandas as pd
 import pandas_profiling
@@ -13,7 +14,7 @@ from dbt.exceptions import CompilationException, DatabaseException, RuntimeExcep
 from streamlit_ace import THEMES, st_ace
 from streamlit_pandas_profiling import st_profile_report
 
-from dbt_osmosis.core.osmosis import DEFAULT_PROFILES_DIR, DbtOsmosis, get_raw_profiles
+from dbt_osmosis.core.osmosis import DEFAULT_PROFILES_DIR, DbtProject
 
 st.set_page_config(page_title="dbt-osmosis Workbench", page_icon="🌊", layout="wide")
 state = st.session_state
@@ -31,7 +32,7 @@ demo_dir = root_path / "demo"
 
 # GLOBAL STATE VARS
 DBT = "DBT"
-"""DbtOsmosis object"""
+"""DbtProject object"""
 PROJ_DIR = "PROJ_DIR"
 """dbt project directory"""
 PROF_DIR = "PROF_DIR"
@@ -45,7 +46,7 @@ state.setdefault(PROF_DIR, _prof_dir or os.getenv("DBT_PROFILES_DIR", DEFAULT_PR
 
 RAW_PROFILES = "RAW_PROFILES"
 """All profiles as parsed from raw profiles yaml"""
-state.setdefault(RAW_PROFILES, get_raw_profiles(state[PROF_DIR]))
+state.setdefault(RAW_PROFILES, dbt_profile.read_profile(state[PROF_DIR] or DEFAULT_PROFILES_DIR))
 
 # SQL WORKBENCH VARS
 SQL_RESULT = "SQL_RESULT"
@@ -165,13 +166,13 @@ state.setdefault(PIVOT_LAYOUT, False)
 def inject_dbt(change_target: Optional[str] = None):
     """Parse dbt project and load context var"""
     if DBT not in state or change_target:
-        dbt_ctx = DbtOsmosis(
+        dbt_ctx = DbtProject(
             project_dir=state[PROJ_DIR],
             profiles_dir=state[PROF_DIR],
             target=change_target,
         )
     else:
-        dbt_ctx: DbtOsmosis = state[DBT]
+        dbt_ctx: DbtProject = state[DBT]
         dbt_ctx.rebuild_dbt_manifest(reset=True)
     state[DBT] = dbt_ctx
     return True
@@ -179,12 +180,12 @@ def inject_dbt(change_target: Optional[str] = None):
 
 if DBT not in state:
     inject_dbt()
-ctx: DbtOsmosis = state[DBT]
+ctx: DbtProject = state[DBT]
 
 TARGET_PROFILE = "TARGET_PROFILE"
 """Target profile for dbt to execute against"""
 
-state.setdefault(TARGET_PROFILE, ctx.profile.target_name)
+state.setdefault(TARGET_PROFILE, ctx.config.target_name)
 
 
 def toggle_viewer() -> None:
@@ -194,7 +195,7 @@ def toggle_viewer() -> None:
 # @st.cache
 def compile_sql(sql: str) -> str:
     try:
-        return ctx.compile_sql(sql)
+        return ctx.compile_sql(sql).compiled_sql
     except CompilationException:
         return None
 
@@ -208,7 +209,7 @@ def run_query(sql: str, limit: int = 2000) -> None:
     else:
         output = [OrderedDict(zip(result.table.column_names, row)) for row in result.table.rows]
         state[SQL_RESULT] = pd.DataFrame(output)
-        state[SQL_ADAPTER_RESP] = result.generated_at
+        state[SQL_ADAPTER_RESP] = result.adapter_response
         state[SQL_QUERY_STATE] = "success"
 
 
@@ -252,8 +253,8 @@ st.sidebar.write(
     "Select a profile used for materializing, compiling, and testing models. Can be updated at any time."
 )
 state[TARGET_PROFILE] = st.sidebar.radio(
-    f"Loaded profiles from {ctx.project.profile_name}",
-    [target for target in state[RAW_PROFILES][ctx.profile.profile_name].get("outputs", [])],
+    f"Loaded profiles from {ctx.config.profile_name}",
+    [target for target in state[RAW_PROFILES][ctx.config.profile_name].get("outputs", [])],
     key=PROFILE_SELECTOR,
 )
 st.sidebar.markdown(f"Current Target: **{state[TARGET_PROFILE]}**")
@@ -329,10 +330,10 @@ if compile_sql(state[RAW_SQL]) != state[COMPILED_SQL]:
     st.experimental_rerun()  # This eager re-run speeds up the app
 
 
-if ctx.profile.target_name != state[TARGET_PROFILE]:  # or state[DBT_DO_RELOAD]:
+if ctx.config.target_name != state[TARGET_PROFILE]:  # or state[DBT_DO_RELOAD]:
     print("Reloading dbt project...")
     with notificationContainer:
-        ctx.profile.target_name = state[TARGET_PROFILE]
+        ctx.config.target_name = state[TARGET_PROFILE]
         ctx.config.target_name = state[TARGET_PROFILE]
         with st.spinner("Reloading dbt... ⚙️"):
             inject_dbt(state[TARGET_PROFILE])
